==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkClipClosedSurface.java <==
// java wrapper for vtkClipClosedSurface object
//

package vtk;
import vtk.*;

public class vtkClipClosedSurface extends vtkPolyDataAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetClippingPlanes_2(vtkPlaneCollection id0);
  public void SetClippingPlanes(vtkPlaneCollection id0)
    { SetClippingPlanes_2(id0); }

  private native long GetClippingPlanes_3();
  public vtkPlaneCollection GetClippingPlanes() {
    long temp = GetClippingPlanes_3();

    if (temp == 0) return null;
    return (vtkPlaneCollection)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetTolerance_4(double id0);
  public void SetTolerance(double id0)
    { SetTolerance_4(id0); }

  private native double GetTolerance_5();
  public double GetTolerance()
    { return GetTolerance_5(); }

  private native void SetPassPointData_6(int id0);
  public void SetPassPointData(int id0)
    { SetPassPointData_6(id0); }

  private native void PassPointDataOn_7();
  public void PassPointDataOn()
    { PassPointDataOn_7(); }

  private native void PassPointDataOff_8();
  public void PassPointDataOff()
    { PassPointDataOff_8(); }

  private native int GetPassPointData_9();
  public int GetPassPointData()
    { return GetPassPointData_9(); }

  private native void SetGenerateOutline_10(int id0);
  public void SetGenerateOutline(int id0)
    { SetGenerateOutline_10(id0); }

  private native void GenerateOutlineOn_11();
  public void GenerateOutlineOn()
    { GenerateOutlineOn_11(); }

  private native void GenerateOutlineOff_12();
  public void GenerateOutlineOff()
    { GenerateOutlineOff_12(); }

  private native int GetGenerateOutline_13();
  public int GetGenerateOutline()
    { return GetGenerateOutline_13(); }

  private native void SetGenerateFaces_14(int id0);
  public void SetGenerateFaces(int id0)
    { SetGenerateFaces_14(id0); }

  private native void GenerateFacesOn_15();
  public void GenerateFacesOn()
    { GenerateFacesOn_15(); }

  private native void GenerateFacesOff_16();
  public void GenerateFacesOff()
    { GenerateFacesOff_16(); }

  private native int GetGenerateFaces_17();
  public int GetGenerateFaces()
    { return GetGenerateFaces_17(); }

  private native void SetScalarMode_18(int id0);
  public void SetScalarMode(int id0)
    { SetScalarMode_18(id0); }

  private native int GetScalarModeMinValue_19();
  public int GetScalarModeMinValue()
    { return GetScalarModeMinValue_19(); }

  private native int GetScalarModeMaxValue_20();
  public int GetScalarModeMaxValue()
    { return GetScalarModeMaxValue_20(); }

  private native void SetScalarModeToNone_21();
  public void SetScalarModeToNone()
    { SetScalarModeToNone_21(); }

  private native void SetScalarModeToColors_22();
  public void SetScalarModeToColors()
    { SetScalarModeToColors_22(); }

  private native void SetScalarModeToLabels_23();
  public void SetScalarModeToLabels()
    { SetScalarModeToLabels_23(); }

  private native int GetScalarMode_24();
  public int GetScalarMode()
    { return GetScalarMode_24(); }

  private native String GetScalarModeAsString_25();
  public String GetScalarModeAsString()
    { return GetScalarModeAsString_25(); }

  private native void SetBaseColor_26(double id0,double id1,double id2);
  public void SetBaseColor(double id0,double id1,double id2)
    { SetBaseColor_26(id0,id1,id2); }

  private native void SetBaseColor_27(double id0[]);
  public void SetBaseColor(double id0[])
    { SetBaseColor_27(id0); }

  private native double[] GetBaseColor_28();
  public double[] GetBaseColor()
    { return GetBaseColor_28(); }

  private native void SetClipColor_29(double id0,double id1,double id2);
  public void SetClipColor(double id0,double id1,double id2)
    { SetClipColor_29(id0,id1,id2); }

  private native void SetClipColor_30(double id0[]);
  public void SetClipColor(double id0[])
    { SetClipColor_30(id0); }

  private native double[] GetClipColor_31();
  public double[] GetClipColor()
    { return GetClipColor_31(); }

  private native void SetActivePlaneId_32(int id0);
  public void SetActivePlaneId(int id0)
    { SetActivePlaneId_32(id0); }

  private native int GetActivePlaneId_33();
  public int GetActivePlaneId()
    { return GetActivePlaneId_33(); }

  private native void SetActivePlaneColor_34(double id0,double id1,double id2);
  public void SetActivePlaneColor(double id0,double id1,double id2)
    { SetActivePlaneColor_34(id0,id1,id2); }

  private native void SetActivePlaneColor_35(double id0[]);
  public void SetActivePlaneColor(double id0[])
    { SetActivePlaneColor_35(id0); }

  private native double[] GetActivePlaneColor_36();
  public double[] GetActivePlaneColor()
    { return GetActivePlaneColor_36(); }

  private native void SetTriangulationErrorDisplay_37(int id0);
  public void SetTriangulationErrorDisplay(int id0)
    { SetTriangulationErrorDisplay_37(id0); }

  private native void TriangulationErrorDisplayOn_38();
  public void TriangulationErrorDisplayOn()
    { TriangulationErrorDisplayOn_38(); }

  private native void TriangulationErrorDisplayOff_39();
  public void TriangulationErrorDisplayOff()
    { TriangulationErrorDisplayOff_39(); }

  private native int GetTriangulationErrorDisplay_40();
  public int GetTriangulationErrorDisplay()
    { return GetTriangulationErrorDisplay_40(); }

  public vtkClipClosedSurface() { super(); }

  public vtkClipClosedSurface(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-17-armv7h.pkg.tar.xz: vtk/vtkClipClosedSurface.java <==
// java wrapper for vtkClipClosedSurface object
//

package vtk;
import vtk.*;

public class vtkClipClosedSurface extends vtkPolyDataAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetClippingPlanes_2(vtkPlaneCollection id0);
  public void SetClippingPlanes(vtkPlaneCollection id0)
    { SetClippingPlanes_2(id0); }

  private native long GetClippingPlanes_3();
  public vtkPlaneCollection GetClippingPlanes() {
    long temp = GetClippingPlanes_3();

    if (temp == 0) return null;
    return (vtkPlaneCollection)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetTolerance_4(double id0);
  public void SetTolerance(double id0)
    { SetTolerance_4(id0); }

  private native double GetTolerance_5();
  public double GetTolerance()
    { return GetTolerance_5(); }

  private native void SetPassPointData_6(int id0);
  public void SetPassPointData(int id0)
    { SetPassPointData_6(id0); }

  private native void PassPointDataOn_7();
  public void PassPointDataOn()
    { PassPointDataOn_7(); }

  private native void PassPointDataOff_8();
  public void PassPointDataOff()
    { PassPointDataOff_8(); }

  private native int GetPassPointData_9();
  public int GetPassPointData()
    { return GetPassPointData_9(); }

  private native void SetGenerateOutline_10(int id0);
  public void SetGenerateOutline(int id0)
    { SetGenerateOutline_10(id0); }

  private native void GenerateOutlineOn_11();
  public void GenerateOutlineOn()
    { GenerateOutlineOn_11(); }

  private native void GenerateOutlineOff_12();
  public void GenerateOutlineOff()
    { GenerateOutlineOff_12(); }

  private native int GetGenerateOutline_13();
  public int GetGenerateOutline()
    { return GetGenerateOutline_13(); }

  private native void SetGenerateFaces_14(int id0);
  public void SetGenerateFaces(int id0)
    { SetGenerateFaces_14(id0); }

  private native void GenerateFacesOn_15();
  public void GenerateFacesOn()
    { GenerateFacesOn_15(); }

  private native void GenerateFacesOff_16();
  public void GenerateFacesOff()
    { GenerateFacesOff_16(); }

  private native int GetGenerateFaces_17();
  public int GetGenerateFaces()
    { return GetGenerateFaces_17(); }

  private native void SetScalarMode_18(int id0);
  public void SetScalarMode(int id0)
    { SetScalarMode_18(id0); }

  private native int GetScalarModeMinValue_19();
  public int GetScalarModeMinValue()
    { return GetScalarModeMinValue_19(); }

  private native int GetScalarModeMaxValue_20();
  public int GetScalarModeMaxValue()
    { return GetScalarModeMaxValue_20(); }

  private native void SetScalarModeToNone_21();
  public void SetScalarModeToNone()
    { SetScalarModeToNone_21(); }

  private native void SetScalarModeToColors_22();
  public void SetScalarModeToColors()
    { SetScalarModeToColors_22(); }

  private native void SetScalarModeToLabels_23();
  public void SetScalarModeToLabels()
    { SetScalarModeToLabels_23(); }

  private native int GetScalarMode_24();
  public int GetScalarMode()
    { return GetScalarMode_24(); }

  private native String GetScalarModeAsString_25();
  public String GetScalarModeAsString()
    { return GetScalarModeAsString_25(); }

  private native void SetBaseColor_26(double id0,double id1,double id2);
  public void SetBaseColor(double id0,double id1,double id2)
    { SetBaseColor_26(id0,id1,id2); }

  private native void SetBaseColor_27(double id0[]);
  public void SetBaseColor(double id0[])
    { SetBaseColor_27(id0); }

  private native double[] GetBaseColor_28();
  public double[] GetBaseColor()
    { return GetBaseColor_28(); }

  private native void SetClipColor_29(double id0,double id1,double id2);
  public void SetClipColor(double id0,double id1,double id2)
    { SetClipColor_29(id0,id1,id2); }

  private native void SetClipColor_30(double id0[]);
  public void SetClipColor(double id0[])
    { SetClipColor_30(id0); }

  private native double[] GetClipColor_31();
  public double[] GetClipColor()
    { return GetClipColor_31(); }

  private native void SetActivePlaneId_32(int id0);
  public void SetActivePlaneId(int id0)
    { SetActivePlaneId_32(id0); }

  private native int GetActivePlaneId_33();
  public int GetActivePlaneId()
    { return GetActivePlaneId_33(); }

  private native void SetActivePlaneColor_34(double id0,double id1,double id2);
  public void SetActivePlaneColor(double id0,double id1,double id2)
    { SetActivePlaneColor_34(id0,id1,id2); }

  private native void SetActivePlaneColor_35(double id0[]);
  public void SetActivePlaneColor(double id0[])
    { SetActivePlaneColor_35(id0); }

  private native double[] GetActivePlaneColor_36();
  public double[] GetActivePlaneColor()
    { return GetActivePlaneColor_36(); }

  private native void SetTriangulationErrorDisplay_37(int id0);
  public void SetTriangulationErrorDisplay(int id0)
    { SetTriangulationErrorDisplay_37(id0); }

  private native void TriangulationErrorDisplayOn_38();
  public void TriangulationErrorDisplayOn()
    { TriangulationErrorDisplayOn_38(); }

  private native void TriangulationErrorDisplayOff_39();
  public void TriangulationErrorDisplayOff()
    { TriangulationErrorDisplayOff_39(); }

  private native int GetTriangulationErrorDisplay_40();
  public int GetTriangulationErrorDisplay()
    { return GetTriangulationErrorDisplay_40(); }

  public vtkClipClosedSurface() { super(); }

  public vtkClipClosedSurface(long id) { super(id); }
  public native long   VTKInit();

}
